==> zio-aws-chimesdkmediapipelines_2.12-6.20.97.2-sources.jar: zio/aws/chimesdkmediapipelines/model/MediaPipelineStatus.scala <==
package zio.aws.chimesdkmediapipelines.model
import scala.jdk.CollectionConverters._
sealed trait MediaPipelineStatus {
  def unwrap: software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus
}
object MediaPipelineStatus {
  def wrap(
      value: software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus
  ): zio.aws.chimesdkmediapipelines.model.MediaPipelineStatus = value match {
    case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus.INITIALIZING =>
      val r = Initializing
      r
    case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus.IN_PROGRESS =>
      val r = InProgress
      r
    case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus.FAILED =>
      val r = Failed
      r
    case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus.STOPPING =>
      val r = Stopping
      r
    case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus.STOPPED =>
      val r = Stopped
      r
    case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus.PAUSED =>
      val r = Paused
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.chimesdkmediapipelines.model.MediaPipelineStatus {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus.UNKNOWN_TO_SDK_VERSION
  }
  case object Initializing
      extends zio.aws.chimesdkmediapipelines.model.MediaPipelineStatus {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus.INITIALIZING
  }
  case object InProgress
      extends zio.aws.chimesdkmediapipelines.model.MediaPipelineStatus {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus.IN_PROGRESS
  }
  case object Failed
      extends zio.aws.chimesdkmediapipelines.model.MediaPipelineStatus {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus.FAILED
  }
  case object Stopping
      extends zio.aws.chimesdkmediapipelines.model.MediaPipelineStatus {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus.STOPPING
  }
  case object Stopped
      extends zio.aws.chimesdkmediapipelines.model.MediaPipelineStatus {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus.STOPPED
  }
  case object Paused
      extends zio.aws.chimesdkmediapipelines.model.MediaPipelineStatus {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus.PAUSED
  }
}

==> zio-aws-chimesdkmediapipelines_2.12-6.20.149.1-sources.jar: zio/aws/chimesdkmediapipelines/model/MediaPipelineStatus.scala <==
package zio.aws.chimesdkmediapipelines.model
import scala.jdk.CollectionConverters._
sealed trait MediaPipelineStatus {
  def unwrap: software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus
}
object MediaPipelineStatus {
  def wrap(
      value: software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus
  ): zio.aws.chimesdkmediapipelines.model.MediaPipelineStatus = value match {
    case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus.INITIALIZING =>
      val r = Initializing
      r
    case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus.IN_PROGRESS =>
      val r = InProgress
      r
    case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus.FAILED =>
      val r = Failed
      r
    case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus.STOPPING =>
      val r = Stopping
      r
    case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus.STOPPED =>
      val r = Stopped
      r
    case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus.PAUSED =>
      val r = Paused
      r
    case software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus.NOT_STARTED =>
      val r = NotStarted
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.chimesdkmediapipelines.model.MediaPipelineStatus {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus.UNKNOWN_TO_SDK_VERSION
  }
  case object Initializing
      extends zio.aws.chimesdkmediapipelines.model.MediaPipelineStatus {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus.INITIALIZING
  }
  case object InProgress
      extends zio.aws.chimesdkmediapipelines.model.MediaPipelineStatus {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus.IN_PROGRESS
  }
  case object Failed
      extends zio.aws.chimesdkmediapipelines.model.MediaPipelineStatus {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus.FAILED
  }
  case object Stopping
      extends zio.aws.chimesdkmediapipelines.model.MediaPipelineStatus {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus.STOPPING
  }
  case object Stopped
      extends zio.aws.chimesdkmediapipelines.model.MediaPipelineStatus {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus.STOPPED
  }
  case object Paused
      extends zio.aws.chimesdkmediapipelines.model.MediaPipelineStatus {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus.PAUSED
  }
  case object NotStarted
      extends zio.aws.chimesdkmediapipelines.model.MediaPipelineStatus {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.MediaPipelineStatus.NOT_STARTED
  }
}
